@@ -67,21 +67,21 @@ class Quora:
     def get_user_stats(user):
         soup = BeautifulSoup(requests.get('http://www.quora.com/' + user).text)
         data_stats = []
-        err = 'no data'
+        err = None
 
         for item in soup.findAll('span', attrs={'class' : 'profile_count'}):
             m = re.findall('\d', str(item))
             element = ''.join(m)
             data_stats.append(element)
 
-        user_dict = {'answers'   : data_stats[1],
+        user_dict = {'answers'   : try_cast(data_stats[1]),
                      'blogs'     : err,
-                     'edits'     : data_stats[5],
-                     'followers' : data_stats[3],
-                     'following' : data_stats[4],
+                     'edits'     : try_cast(data_stats[5]),
+                     'followers' : try_cast(data_stats[3]),
+                     'following' : try_cast(data_stats[4]),
                      'name'      : user,
-                     'posts'     : data_stats[2],
-                     'questions' : data_stats[0],
+                     'posts'     : try_cast(data_stats[2]),
+                     'questions' : try_cast(data_stats[0]),
                      'topics'    : err,
                      'username'  : user }
         return user_dict
